@@ -1,11 +1,11 @@
 package Data::DPath;
-# git description: v0.51-9-ga9c0a52
+# git description: v0.53-6-gb2f11f9
 
 BEGIN {
   $Data::DPath::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: DPath is not XPath!
-$Data::DPath::VERSION = '0.52';
+$Data::DPath::VERSION = '0.54';
 use 5.008;
 use strict;
 use warnings;
@@ -57,6 +57,11 @@ sub match {
         Data::DPath::Path->new(path => $path_str)->match($data);
 }
 
+sub matchr {
+        my ($class, $data, $path_str) = @_;
+        Data::DPath::Path->new(path => $path_str)->matchr($data);
+}
+
 # ------------------------------------------------------------
 
 1;
@@ -371,6 +376,10 @@ See chapter L<Iterator style|/"Iterator style"> below for details.
 
 Returns an array of all values in C<$data> that match the C<$path>.
 
+=head2 matchr( $data, $path )
+
+Returns an array ref of all values in C<$data> that match the C<$path>.
+
 =head1 OPERATOR
 
 =head2 ~~
