@@ -3,7 +3,7 @@ BEGIN {
   $Data::DPath::Context::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Abstraction for a current context that enables incremental searches
-$Data::DPath::Context::VERSION = '0.53';
+$Data::DPath::Context::VERSION = '0.54';
 use strict;
 use warnings;
 
@@ -30,8 +30,8 @@ BEGIN {
 BEGIN {
   $Data::DPath::Filters::AUTHORITY = 'cpan:SCHWIGON';
 }
-$Data::DPath::Filters::VERSION = '0.53';
-        $COMPARTMENT = Safe->new;
+$Data::DPath::Filters::VERSION = '0.54';
+$COMPARTMENT = Safe->new;
         $COMPARTMENT->permit(qw":base_core");
         # map DPath filter functions into new namespace
         $COMPARTMENT->share(qw(affe
@@ -151,14 +151,21 @@ sub _any
 sub _all {
         my ($self) = @_;
 
+        return @{$self->_all_ref};
+}
+
+sub _all_ref {
+        my ($self) = @_;
+
         no strict 'refs';
         no warnings 'uninitialized';
 
-        return
-          map { $self->give_references ? $_ : $$_ }
-          uniq
-          map { defined $_ ? $_->ref : () }
-          @{$self->current_points};
+        return [
+                map { $self->give_references ? $_ : $$_ }
+                uniq
+                map { defined $_ ? $_->ref : () }
+                @{$self->current_points}
+            ];
 }
 
 # filter current results by array index
@@ -471,6 +478,12 @@ sub match {
         $self->_search($dpath)->_all;
 }
 
+sub matchr {
+        my ($self, $dpath) = @_;
+
+        $self->_search($dpath)->_all_ref;
+}
+
 1;
 
 __END__
@@ -502,7 +515,11 @@ matched points in the data structure.
 
 =head2 match( $dpath )
 
-Return all data that match the given DPath.
+Return array of all data that match the given DPath.
+
+=head2 matchr( $dpath )
+
+Return array ref of all data that match the given DPath.
 
 =head2 isearch( $path_str )
 
