@@ -3,7 +3,7 @@ BEGIN {
   $Data::DPath::Path::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: Abstraction for a DPath
-$Data::DPath::Path::VERSION = '0.53';
+$Data::DPath::Path::VERSION = '0.54';
 use strict;
 use warnings;
 
@@ -60,7 +60,7 @@ eval 'use overload "~~" => \&op_match' if $] >= 5.010;
 sub op_match {
         my ($self, $data, $rhs) = @_;
 
-        return [ $self->match( $data ) ];
+        return $self->matchr( $data );
 }
 
 # essentially the Path parser
@@ -133,11 +133,17 @@ sub _build__steps {
 sub match {
         my ($self, $data) = @_;
 
+        return @{$self->matchr($data)};
+}
+
+sub matchr {
+        my ($self, $data) = @_;
+
         my $context = Context
             ->new
                 ->current_points([ Point->new->ref(\$data) ])
                     ->give_references($self->give_references);
-        return $context->match($self);
+        return $context->matchr($self);
 }
 
 1;
@@ -177,6 +183,10 @@ matched points in the data structure.
 
 Returns an array of all values in C<$data> that match the Path object.
 
+=head2 matchr( $data )
+
+Returns an array ref of all values in C<$data> that match the Path object.
+
 =head1 INTERNAL METHODS
 
 =head2 op_match( $self, $data )
